Summary:        RPKI client implementation
Name:           rpki-client
Version:        0.3.0
Release:        1%{?dist}
License:        ISC
URL:            https://github.com/kristapsdz/rpki-client/
Source0:        https://github.com/kristapsdz/rpki-client/archive/VERSION_%{vcs_ver}/%{name}-%{version}.tar.gz
Source1:        TALs.md
Patch0:         rpki-client-0.3.0-541b2a0.patch
BuildRequires:  gcc
%if 0%{?fedora} || 0%{?rhel} >= 8
BuildRequires:  openssl-devel >= 1.1.0
%else
BuildRequires:  openssl11-devel
%endif
BuildRequires:  zlib-devel
Requires:       rsync
Requires(pre):  shadow-utils

%global vcs_ver %(echo %{version} | tr . _)

%description
rpki-client is an implementation of RPKI (Resource Public Key
Infrastructure), specified by RFC 6480. It implements the client
side of RPKI, which is responsible for downloading, validating
and converting ROAs (Route Origin Authorisations) into VRPs
(Validated ROA Payloads). The client's output (VRPs) can be used
to perform BGP Origin Validation (RFC 6811).

The design focus of rpki-client is simplicity and security. To
wit, it implements RPKI components necessary for validating route
statements and omits superfluities (such as, for example, which
X509 certificate sections must be labelled "Critical").

%prep
%setup -q -n %{name}-VERSION_%{vcs_ver}
%patch0 -p1 -b .541b2a0
cp -pf %{SOURCE1} .

%build
cat > configure.local <<EOF
PREFIX=%{_prefix}
MANDIR=%{_mandir}
INSTALL_PROGRAM='install -p -m 0755'
INSTALL_LIB='install -p -m 0644'
INSTALL_MAN='install -p -m 0644'
INSTALL_DATA='install -p -m 0644'
%if 0%{?fedora} || 0%{?rhel} >= 8
CFLAGS+=" $RPM_OPT_FLAGS $(pkg-config --cflags openssl)"
LDFLAGS+=" $RPM_LD_FLAGS $(pkg-config --libs openssl) -lresolv"
%else
CFLAGS+=" $RPM_OPT_FLAGS $(pkg-config --cflags openssl11)"
LDFLAGS+=" $RPM_LD_FLAGS $(pkg-config --libs openssl11) -lresolv"
%endif
EOF

./configure
%make_build \
  RPKI_PRIVDROP_USER=%{name} \
  RPKI_RSYNC_COMMAND=rsync \
  RPKI_PATH_OUT_DIR=%{_localstatedir}/lib/%{name} \
  RPKI_PATH_BASE_DIR=%{_localstatedir}/cache/%{name} \
  RPKI_TAL_DIR=%{_sysconfdir}/pki/tals

%install
%make_install
mkdir -p $RPM_BUILD_ROOT{%{_localstatedir}/{cache,lib}/%{name},%{_sysconfdir}/pki/tals}/
install -p -m 0644 tals/*.tal $RPM_BUILD_ROOT%{_sysconfdir}/pki/tals/

%pre
getent group %{name} > /dev/null || %{_sbindir}/groupadd -r %{name}
getent passwd %{name} > /dev/null || %{_sbindir}/useradd -r -g %{name} -d %{_localstatedir}/lib/%{name} -s /sbin/nologin -c "RPKI client" %{name}
exit 0

%files
%license LICENSE.md
%doc README.md TALs.md
%{_bindir}/%{name}
%{_sysconfdir}/pki/tals/
%{_mandir}/man8/%{name}.8*
%dir %attr(0750,%{name},%{name}) %{_localstatedir}/cache/%{name}/
%dir %attr(0750,%{name},%{name}) %{_localstatedir}/lib/%{name}/

%changelog
* Mon Feb 24 2020 Robert Scheck <robert@fedoraproject.org> 0.3.0-1
- Upgrade to 0.3.0 (#1806049)
- Install bundled Trust Anchor Locators (TALs)

* Thu Jan 30 2020 Fedora Release Engineering <releng@fedoraproject.org> - 0.2.0-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_32_Mass_Rebuild

* Wed Jun 19 2019 Robert Scheck <robert@fedoraproject.org> 0.2.0-1
- Upgrade to 0.2.0 (#1745770)
- Initial spec file for Fedora and Red Hat Enterprise Linux
